# from aiohttp import web
# from sqlalchemy.orm import Session
# from apps.auth.models import User
# from config.database import get_db
# from utils.response import format_response
# import bcrypt

# async def signup(request):
#     db: Session = next(get_db())
#     try:
#         data = await request.json()
#         email = data.get('email')
#         username = data.get('username')
#         password = data.get('password')

#         if not email or not username or not password:
#             return web.json_response(format_response('error', 'Missing credentials'))

#         user = db.query(User).filter(User.email == email).first()
#         if user:
#             return web.json_response(format_response('error', 'Email already exists'))

#         hashed_password = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt())
#         new_user = User(email=email, username=username, password=hashed_password)
#         db.add(new_user)
#         db.commit()

#         # Send a welcome email
#         from utils.email import send_welcome_email
#         await send_welcome_email(email, username)

#         return web.json_response(format_response('success', 'User registered successfully'))
#     except Exception as e:
#         print(f"Error during signup: {e}")
#         return web.json_response(format_response('error', 'Signup failed'))
#     finally:
#         db.close()

# async def login(request):
#     db: Session = next(get_db())
#     try:
#         data = await request.json()
#         email = data.get('email')
#         password = data.get('password')

#         user = db.query(User).filter(User.email == email).first()

#         if user and bcrypt.checkpw(password.encode('utf-8'), user.password):
#             return web.json_response(format_response('success', f'Welcome {user.username}'))
#         else:
#             return web.json_response(format_response('error', 'Invalid credentials'))
#     except Exception as e:
#         print(f"Error during login: {e}")
#         return web.json_response(format_response('error', 'Login failed'))
#     finally:
#         db.close()


# apps/auth/views.py

from aiohttp import web
from sqlalchemy.orm import Session
from apps.auth.models import User
from config.database import get_db
from utils.response import format_response
import bcrypt
from apps.auth.serializers import serialize_user  # Importing the serializer

async def signup(request):
    db: Session = next(get_db())
    try:
        data = await request.json()
        email = data.get('email')
        username = data.get('username')
        password = data.get('password')

        if not email or not username or not password:
            return web.json_response(format_response('error', 'Missing credentials'))

        user = db.query(User).filter(User.email == email).first()
        if user:
            return web.json_response(format_response('error', 'Email already exists'))

        hashed_password = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt()).decode('utf-8')
        new_user = User(email=email, username=username, password=hashed_password)
        db.add(new_user)
        db.commit()

        # Send a welcome email
        from utils.email import send_welcome_email
        await send_welcome_email(email, username)

        # Serialize the newly created user
        serialized_user = serialize_user(new_user)
        return web.json_response(format_response('success', 'User registered successfully', serialized_user))
    except Exception as e:
        print(f"Error during signup: {e}")
        return web.json_response(format_response('error', 'Signup failed'))
    finally:
        db.close()

async def login(request):
    db: Session = next(get_db())
    try:
        data = await request.json()
        email = data.get('email')
        password = data.get('password')

        user = db.query(User).filter(User.email == email).first()

        if user and bcrypt.checkpw(password.encode('utf-8'), user.password.encode('utf-8')):
            serialized_user = serialize_user(user)
            return web.json_response(format_response('success', f'Welcome {user.username}', serialized_user))
        else:
            return web.json_response(format_response('error', 'Invalid credentials'))
    except Exception as e:
        print(f"Error during login: {e}")
        return web.json_response(format_response('error', 'Login failed'))
    finally:
        db.close()
